aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/security/handshake.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/security/handshake.h')
-rw-r--r--src/core/security/handshake.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/core/security/handshake.h b/src/core/security/handshake.h
index 1739855d69..d7e4a30580 100644
--- a/src/core/security/handshake.h
+++ b/src/core/security/handshake.h
@@ -38,8 +38,9 @@
#include "src/core/security/security_connector.h"
-/* Calls the callback upon completion. */
-void grpc_do_security_handshake(grpc_security_connector *connector,
+/* Calls the callback upon completion. Takes owership of handshaker. */
+void grpc_do_security_handshake(tsi_handshaker *handshaker,
+ grpc_security_connector *connector,
grpc_endpoint *nonsecure_endpoint,
grpc_security_handshake_done_cb cb,
void *user_data);